@@ -8,6 +8,6 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 
-from ._deployment_helpers import make_slot_deployment_dir, trigger_deployment
+from ._deployment_helpers import make_slot_deployment_dir
